@@ -62,9 +62,9 @@ class Engine():
                     "metadata": kwargs,
                     "step": step}
         if checkpoint_path:
-            dst_state_path = f"{self.meta['experimentUrl']}/weights"
+            dst_state_path = f"{self.meta['experimentUrl']}/weights/"
             os.system(f"gsutil cp {checkpoint_path} {dst_state_path} 2> /dev/null")
-            artifact["metadata"]["checkpoint"] = f"{dst_state_path}/{checkpoint_path.split('/')[-1]}"
+            artifact["metadata"]["checkpoint"] = f"{dst_state_path}{checkpoint_path.split('/')[-1]}"
             
             if best:
                 self.dione.add_best_model(self.experimentId, artifact["metadata"]["checkpoint"])
